@@ -1,12 +1,14 @@
 package WordList::SU::LTIS;
 
 our $DATE = '2016-01-13'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
+
+use utf8;
 
 use WordList;
 our @ISA = qw(WordList);
 
-our %STATS = ("num_words_contains_nonword_chars",573,"num_words",4167,"shortest_word_len",2,"longest_word_len",19,"num_words_contains_unicode",572,"avg_word_len",7.44324454043676,"num_words_contains_whitespace",0); # STATS
+our %STATS = ("num_words_contains_unicode",572,"avg_word_len",7.28101751859851,"longest_word_len",18,"shortest_word_len",2,"num_words",4167,"num_words_contains_nonword_chars",1,"num_words_contains_whitespace",0); # STATS
 
 1;
 # ABSTRACT: Sundanese words from Loka Tarjamah Otomatis Indonesia-Sunda
@@ -24,7 +26,7 @@ WordList::SU::LTIS - Sundanese words from Loka Tarjamah Otomatis Indonesia-Sunda
 
 =head1 VERSION
 
-This document describes version 0.03 of WordList::SU::LTIS (from Perl distribution WordList-SU-LTIS), released on 2016-01-13.
+This document describes version 0.04 of WordList::SU::LTIS (from Perl distribution WordList-SU-LTIS), released on 2016-01-13.
 
 =head1 SYNOPSIS
 
@@ -50,10 +52,10 @@ This document describes version 0.03 of WordList::SU::LTIS (from Perl distributi
  +----------------------------------+------------------+
  | key                              | value            |
  +----------------------------------+------------------+
- | avg_word_len                     | 7.44324454043676 |
- | longest_word_len                 | 19               |
+ | avg_word_len                     | 7.28101751859851 |
+ | longest_word_len                 | 18               |
  | num_words                        | 4167             |
- | num_words_contains_nonword_chars | 573              |
+ | num_words_contains_nonword_chars | 1                |
  | num_words_contains_unicode       | 572              |
  | num_words_contains_whitespace    | 0                |
  | shortest_word_len                | 2                |
